@@ -70,7 +70,6 @@ public:
      */
     typedef struct keyword
     {
-    public:
         const char *name;           /**< name of command */
         method_t method;    /**< runtime method or NULL if c-t only */
         check_t check;              /**< compile-time check routine */
@@ -86,10 +85,12 @@ public:
      */
     class __EXPORT strict : public LinkedObject
     {
+    private:
+        __DELETE_DEFAULTS(strict);
+
     public:
         const char *id;
 
-    public:
         static bool find(Script *img, header *scr, const char *id);
         static void createVar(Script *img, header *scr, const char *id);
         static void createSym(Script *img, header *scr, const char *id);
@@ -108,6 +109,9 @@ public:
      */
     class __EXPORT symbol : public LinkedObject
     {
+    private:
+        __DELETE_DEFAULTS(symbol);
+
     public:
         const char *name;   /**< name of symbol */
         char *data;         /**< content of symbol */
@@ -122,6 +126,9 @@ public:
      */
     class __EXPORT event : public LinkedObject
     {
+    private:
+        __DELETE_DEFAULTS(event);
+
     public:
         line_t *first;
         const char *name;
@@ -142,6 +149,9 @@ public:
      */
     class __EXPORT header : public LinkedObject
     {
+    private:
+        __DELETE_DEFAULTS(header);
+
     public:
         LinkedObject *scoped;   /**< scoped symbol defs */
         LinkedObject *events;   /**< named events */
@@ -168,6 +178,9 @@ public:
      */
     class __EXPORT checks
     {
+    private:
+        __DELETE_DEFAULTS(checks);
+
     public:
         static bool isValue(const char *text);
         static bool isText(const char *text);
@@ -346,6 +359,8 @@ public:
         const char *getIndex(void);
 
     private:
+        __DELETE_COPY(interp);
+
         bool getExpression(unsigned index);
 
         char *errmsg;
@@ -363,6 +378,9 @@ public:
     {
     private:
         friend class Script;
+
+        __DELETE_DEFAULTS(error);
+
         error(Script *img, unsigned line, const char *str);
 
     public:
@@ -380,6 +398,9 @@ public:
      */
     class __EXPORT methods : public interp
     {
+    private:
+        __DELETE_DEFAULTS(methods);
+
     public:
         bool scrPush(void);
         bool scrApply(void);
@@ -503,6 +524,8 @@ private:
     friend class interp;
     friend class methods;
 
+    __DELETE_COPY(Script);
+
     Script();
 
     void errlog(unsigned line, const char *fmt, ...);
