@@ -104,7 +104,7 @@ const char *Script::interp::getFormat(Script::symbol *sym, const char *id, char
 
     static char null[1] = {0};
 
-    unsigned dcount = 0, pos;
+    size_t dcount = 0, pos;
     char *cp;
     char *ep;
     char idbuf[32];
