@@ -459,7 +459,7 @@ Script *Script::compile(Script *merge, const char *fn, Script *cfg)
     const char *cp;
     bool requires = false;
     char *ep;
-    unsigned len;
+    size_t len;
 
     if(!cf.is_open()) {
         if(merge)
@@ -1267,7 +1267,7 @@ void Script::copy(const char *list, char *item, unsigned size)
 unsigned Script::offset(const char *list, unsigned index)
 {
     const char *cp = get(list, index);
-    return cp - list;
+    return (unsigned)(cp - list);
 }
 
 const char *Script::get(const char *list, unsigned index)
