@@ -35,6 +35,9 @@ static unsigned manipchecks = 0;
 
 class debug
 {
+private:
+    __DELETE_COPY(debug);
+
 public:
     debug();
 
@@ -45,7 +48,12 @@ public:
 
 class testing : public debug, public Script::interp
 {
+private:
+    __DELETE_COPY(testing);
+
 public:
+    inline testing() : debug(), Script::interp() {}
+
     bool scrCheck(void);
     bool scrCheckExit(void);
     bool scrCheckMain(void);
